#!/bin/bash
# Remote build script (iboernig@suse.de)
# $Id: build.sh,v 1.15 2002/10/17 13:11:35 joergs Exp $
#
# Kurze Featuritis:
# - build.sh sollte im Pfad liegen. 
#	Ein Link von ~/bin/build.sh ist eine gute Wahl ;)
# - ohne Parameter aufgerufen, 
#   erzeugt build.sh mit Hilfe des Makefiles in aktuellen Verzeichnis
#   ein tar-Archiv, bertrgt dieses nach Oldwotan und baut es dort
# - mit Parameter geht das Skript davon aus, 
#	dass der Parameter ein SRPM Paket ist.
#	Dieses wird nach oldwotan kopiert, dort entpackt und dann gebaut.
# - Dazu muss ein ssh-pubkey in oldwotans /root/.ssh/authorized_keys gelegt 
#   werden (build.sh verwendet ssh)
# Wichtige Einstellungen:
# - Standardmig baut build.sh mit --clean, wenns schnell gehen soll, die 
#   Umgebungsvariable BUILD_MODE="--no-init" exportieren
# - BUILD_DIST ist standard sles7-i386, kann auch durch entsprechenden Export
#   berschrieben werden.
# - die fertigen Pakete werden nach DEST_DIR (kann durch env gesetzt werden) 
#   in die vorgegebene Hierarchie (src, i386/sles/7) auf den lokalen Rechner 
#   kopiert. Vorgabe ist /tmp/smartclient_build

SSH_VERSION="1"
BUILDHOST="oldwotan"
FQBUILDHOST="$BUILDHOST.suse.de"
BUILDTEMP=abuildtmp
BUILDUSER=$USER

[ -z "$BUILD_MODE" ] && BUILD_MODE="--verify"
[ -z "$BUILD_DIST" ] && BUILD_DIST="sles7-i386+update"
[ -z "$BUILD_ROOT" ] && BUILD_ROOT="/abuild/buildsystem.$BUILDHOST.$USER.$BUILD_DIST.smartclient"
[ -z "$BUILD_PREPARE_SPEC" ] && BUILD_PREPARE_SPEC="no"

[ -z $DEST_DIR ] && DEST_DIR="/tmp/smartclient_build/"

ERROR=0

# Hier gehts los:

if [ -z "$1" ]; then
	# without parameter, we are in source directory
	test -e Makefile && make
	SPECFILE=$(ls *.spec | awk '{print $1}')
	TARFILE=$(ls  *.tar.[gb]z*| awk '{print $1}')
	PACKAGE=$(awk '/^Name:/ {print $2}' <$SPECFILE)
	VERSION=$(awk '/^Version:/ {print $2}' <$SPECFILE)
	SRC_FILES="$SPECFILE $TARFILE"
else
	# parameter is src.rpm file
	PACKAGE=`echo $1 | sed 's/-[0-9]*\..*.src.rpm//'`
	VERSION=`echo $1 | sed 's/.*-\([0-9]*\..*\)-.*.src.rpm/\1/'`
	SRC_FILES="$1"
fi

echo $PACKAGE $VERSION $BUILD_DIST $BUILD_MODE

# Cleaning up and install tempdir
ssh -${SSH_VERSION} ${FQBUILDHOST} "\
	rm -r ${BUILDTEMP}/src/${PACKAGE}; \
	mkdir -p ${BUILDTEMP}/src/${PACKAGE} ${BUILDTEMP}/${BUILD_DIST}";

scp -oProtocol=$SSH_VERSION $SRC_FILES ${FQBUILDHOST}:${BUILDTEMP}/src/${PACKAGE}

if [ "$1" ]; then
	ssh -${SSH_VERSION} ${FQBUILDHOST} "\
		cd ${BUILDTEMP}/src/${PACKAGE}; rpm2cpio $1 | cpio -i";
fi

# create buildscript

cat > /tmp/tmpscript.$$ <<EOF
#!/bin/bash
# local buildscript
. /work/src/bin/.profile
export BUILD_ROOT=$BUILD_ROOT
export BUILD_DIST=$BUILD_DIST
export BUILD_PREPARE_SPEC=$BUILD_PREPARE_SPEC

cd ~${BUILDUSER}/${BUILDTEMP}/src/${PACKAGE}
build $BUILD_MODE --prefer-rpms ~${BUILDUSER}/${BUILDTEMP}/${BUILD_DIST}
EOF

#cat /tmp/tmpscript.$$

scp -oProtocol=$SSH_VERSION /tmp/tmpscript.$$ ${FQBUILDHOST}:${BUILDTEMP}/src/${PACKAGE}/buildscript
rm /tmp/tmpscript.$$

# build and file rpms
ssh -oProtocol=$SSH_VERSION root@${FQBUILDHOST} \
	. ~$BUILDUSER/${BUILDTEMP}/src/${PACKAGE}/buildscript
ssh -oProtocol=$SSH_VERSION ${FQBUILDHOST} \
	"rm -f ${BUILDTEMP}/${BUILD_DIST}/${PACKAGE}-*.*.rpm;\
	cp ${BUILD_ROOT}/usr/src/packages/RPMS/*/${PACKAGE}-${VERSION}-*.*.rpm ${BUILDTEMP}/${BUILD_DIST}/"

mkdir -p ${DEST_DIR}/src
# delete all old versions of this package
rm -f ${DEST_DIR}/src/${PACKAGE}-*.src.rpm
if !(scp -oProtocol=$SSH_VERSION root@${FQBUILDHOST}:${BUILD_ROOT}/usr/src/packages/SRPMS/${PACKAGE}-${VERSION}-*.src.rpm ${DEST_DIR}/src ); then 
	ERROR=1
fi

mkdir -p ${DEST_DIR}/${BUILD_DIST}
# delete all old versions of this package
rm -f ${DEST_DIR}/${BUILD_DIST}/${PACKAGE}-*.rpm
if !(scp -oProtocol=$SSH_VERSION root@${FQBUILDHOST}:${BUILD_ROOT}/usr/src/packages/RPMS/*/${PACKAGE}-${VERSION}-*.*.rpm ${DEST_DIR}/${BUILD_DIST} ); then 
	ERROR=2
fi

if [ $ERROR -ne 0 ]; then
    echo "ERROR while building packet $PACKAGE";
	for i in `seq 5`; do
		echo -n "";
	done
else
	echo "Build of ${PACKAGE} completed!"
	echo "Packages can be found in ${DEST_DIR}"
fi

exit $ERROR
